==> kubernetes-model-batch-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/JobConditionBuilder.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class JobConditionBuilder extends JobConditionFluentImpl<JobConditionBuilder> implements VisitableBuilder<JobCondition,JobConditionBuilder>{
  public JobConditionBuilder() {
    this(false);
  }
  public JobConditionBuilder(Boolean validationEnabled) {
    this(new JobCondition(), validationEnabled);
  }
  public JobConditionBuilder(JobConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public JobConditionBuilder(JobConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new JobCondition(), validationEnabled);
  }
  public JobConditionBuilder(JobConditionFluent<?> fluent,JobCondition instance) {
    this(fluent, instance, false);
  }
  public JobConditionBuilder(JobConditionFluent<?> fluent,JobCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withLastProbeTime(instance.getLastProbeTime());
      fluent.withLastTransitionTime(instance.getLastTransitionTime());
      fluent.withMessage(instance.getMessage());
      fluent.withReason(instance.getReason());
      fluent.withStatus(instance.getStatus());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public JobConditionBuilder(JobCondition instance) {
    this(instance,false);
  }
  public JobConditionBuilder(JobCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withLastProbeTime(instance.getLastProbeTime());
      this.withLastTransitionTime(instance.getLastTransitionTime());
      this.withMessage(instance.getMessage());
      this.withReason(instance.getReason());
      this.withStatus(instance.getStatus());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  JobConditionFluent<?> fluent;
  Boolean validationEnabled;
  public JobCondition build() {
    JobCondition buildable = new JobCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-batch-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/batch/v1/JobConditionBuilder.java <==
package io.fabric8.kubernetes.api.model.batch.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class JobConditionBuilder extends JobConditionFluent<JobConditionBuilder> implements VisitableBuilder<JobCondition,JobConditionBuilder>{
  public JobConditionBuilder() {
    this(false);
  }
  public JobConditionBuilder(Boolean validationEnabled) {
    this(new JobCondition(), validationEnabled);
  }
  public JobConditionBuilder(JobConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public JobConditionBuilder(JobConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new JobCondition(), validationEnabled);
  }
  public JobConditionBuilder(JobConditionFluent<?> fluent,JobCondition instance) {
    this(fluent, instance, false);
  }
  public JobConditionBuilder(JobConditionFluent<?> fluent,JobCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new JobCondition());

    if (instance != null) {
      fluent.withLastProbeTime(instance.getLastProbeTime());
      fluent.withLastTransitionTime(instance.getLastTransitionTime());
      fluent.withMessage(instance.getMessage());
      fluent.withReason(instance.getReason());
      fluent.withStatus(instance.getStatus());
      fluent.withType(instance.getType());
      fluent.withLastProbeTime(instance.getLastProbeTime());
      fluent.withLastTransitionTime(instance.getLastTransitionTime());
      fluent.withMessage(instance.getMessage());
      fluent.withReason(instance.getReason());
      fluent.withStatus(instance.getStatus());
      fluent.withType(instance.getType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public JobConditionBuilder(JobCondition instance) {
    this(instance,false);
  }
  public JobConditionBuilder(JobCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new JobCondition());

    if (instance != null) {
      this.withLastProbeTime(instance.getLastProbeTime());
      this.withLastTransitionTime(instance.getLastTransitionTime());
      this.withMessage(instance.getMessage());
      this.withReason(instance.getReason());
      this.withStatus(instance.getStatus());
      this.withType(instance.getType());
      this.withLastProbeTime(instance.getLastProbeTime());
      this.withLastTransitionTime(instance.getLastTransitionTime());
      this.withMessage(instance.getMessage());
      this.withReason(instance.getReason());
      this.withStatus(instance.getStatus());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  JobConditionFluent<?> fluent;
  Boolean validationEnabled;
  public JobCondition build() {
    JobCondition buildable = new JobCondition(fluent.getLastProbeTime(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
